@@ -1,4 +1,5 @@
-# Copyright 2021 MosaicML. All Rights Reserved.
+# Copyright 2022 MosaicML Composer authors
+# SPDX-License-Identifier: Apache-2.0
 
 from __future__ import annotations
 
@@ -45,11 +46,11 @@ def factorizing_could_speedup(module: torch.nn.Module, latent_size: Union[int, f
     and more per-op overhead.
 
     Args:
-        module (torch.nn.Module): a :py:class:`~torch.nn.Conv2d`, :py:class:`~torch.nn.Linear`,
-            :py:class:`~FactorizedConv2d`, or :py:class:`~FactorizedLinear`.
-        latent_size (int or float): number of channels (for convolution) or
+        module (:class:`torch.nn.Module`): a :class:`~torch.nn.Conv2d`, :class:`~torch.nn.Linear`,
+            :class:`~FactorizedConv2d`, or :class:`~FactorizedLinear`.
+        latent_size (int | float): number of channels (for convolution) or
             features (for linear) in the latent representation. Can be
-            specified as either an integer > 1 or as float within [0, 1).
+            specified as either an integer > 1 or as float within ``[0, 1)``.
             In the latter case, the value is interpreted as a fraction of
             ``min(in_features, out_features)`` for a linear module or
             ``min(in_channels, out_channels)`` for a convolution.
@@ -138,8 +139,8 @@ class _FactorizedModule(nn.Module, abc.ABC):
         latent rank.
 
         Args:
-            input: Tensor that can be passed to the model's `forward()` method
-            rank: dimensionality of the latent representation; this is the
+            input (:class:`torch.Tensor`): Tensor that can be passed to the model's `forward()` method.
+            rank (int): dimensionality of the latent representation; this is the
                 size of the vector space when factorizing linear modules and
                 the number of channels for convolutional modules.
 
@@ -184,11 +185,11 @@ class _FactorizedModule(nn.Module, abc.ABC):
         many possible solutions for a given module before choosing one.
 
         Args:
-            input: An input to the module used to optimize the solution's
+            input (:class:`torch.Tensor`): An input to the module used to optimize the solution's
                 weights. The optimization seeks to preserve the module's
-                input-output mapping as much as possible subject to the
+                input-output mapping as much as possible, subject to the
                 specified rank constraint.
-            rank: The number of dimensions in the latent space into which
+            rank (int): The number of dimensions in the latent space into which
                 the input is mapped.
 
         Returns:
@@ -206,9 +207,9 @@ class _FactorizedModule(nn.Module, abc.ABC):
         using the solution is worthwhile.
 
         Args:
-            solution: an object encapsulating the new parameters to be used
-                and their associated mean squared error on the input for
-                which they were optimized. Can be obtained using
+            solution (:class:`LowRankSolution`): an object encapsulating the new 
+                parameters to be used and their associated mean squared error on 
+                the input for which they were optimized. Can be obtained using
                 :meth:`~solution_for_rank`.
         """
         ...
@@ -221,30 +222,31 @@ class FactorizedConv2d(_FactorizedModule):
     are executed sequentially with no nonlinearity in between. This first
     conv2d can be thought of as projecting the feature maps into a
     lower-dimensional space, similar to PCA. The second produces outputs
-    of the same shape as the un-factorized version based on the embeddings
+    of the same shape as the unfactorized version based on the embeddings
     within this lower-dimensional space. Note that "dimensionality" here
     refers to the number of channels, not the spatial extent or tensor rank.
 
     The first conv2d has a kernel size of ``kernel_size``, while the second
-    one always has a kernel size of 1x1. For large kernel sizes, the
+    one always has a kernel size of :math:`1 \\times 1`. For large kernel sizes, the
     lower-dimensional space can be nearly as large as
     ``min(in_channels, out_channels)`` and still yield a reduction in
-    multiply-add operations. For kernels sizes of 1x1, the breakeven
+    multiply-add operations. For kernels sizes of :math:`1 \\times 1`, the breakeven
     point is a 2x reduction in channel count, similar to
     :class:`~FactorizedLinear`.
 
     See :func:`~composer.factorize.factorize_conv2d` for more details.
 
     Args:
-        in_channels (int): number of channels in the input image
-        out_channels (int): number of channels produced by the convolution
-        kernel_size (int or tuple, optional): size of the convolving kernel
-        latent_channels (int or float, optional): number of channels in the
+        in_channels (int): number of channels in the input image.
+        out_channels (int): number of channels produced by the convolution.
+        kernel_size (int | tuple): size of the convolving kernel.
+        latent_channels (int | float, optional): number of channels in the
             latent representation produced by the first small convolution.
             Can be specified as either an integer > 1 or as float within
-            [0, 1). In the latter case, the value is interpreted as a fraction
-            of ``min(in_features, out_features)`` for each linear module, and
+            ``[0, 1)``. In the latter case, the value is interpreted as a fraction
+            of ``min(in_features, out_features)`` for each linear module and
             is converted to the equivalent integer value, with a minimum of 1.
+            Default: ``.25``.
         **kwargs: other arguments to :class:`torch.nn.Conv2d` are supported
             and will be used with the first of the two smaller ``Conv2d``
             operations. However, ``groups > 1`` and ``dilation > 1`` are
@@ -335,9 +337,9 @@ class FactorizedConv2d(_FactorizedModule):
         """Returns the largest latent channel count that reduces the number of multiply-adds.
 
         Args:
-            in_channels: number of channels in the input image
-            out_channels: number of channels produced by the convolution
-            kernel_size: size of the convolving kernel
+            in_channels (int): number of channels in the input image
+            out_channels (int): number of channels produced by the convolution
+            kernel_size (int | tuple): size of the convolving kernel
 
         Returns:
             latent_channels: the largest allowable number of latent channels
@@ -364,11 +366,11 @@ class FactorizedConv2d(_FactorizedModule):
 class FactorizedLinear(_FactorizedModule):
     """Factorized replacement for :class:`torch.nn.Linear`.
 
-    Splits the linear operation into two smaller linear operations, which
+    Splits the linear operation into two smaller linear operations which
     are executed sequentially with no nonlinearity in between. This first
     linear operation can be thought of as projecting the inputs into a
     lower-dimensional space, similar to PCA. The second produces outputs
-    of the same shape as the un-factorized version based on the embeddings
+    of the same shape as the unfactorized version based on the embeddings
     within this lower-dimensional space.
 
     If the lower-dimensional space is less than half the size of the
@@ -383,12 +385,13 @@ class FactorizedLinear(_FactorizedModule):
     Args:
         in_features (int): size of each input sample
         out_features (int): size of each output sample
-        bias (bool): If set to False, the layer will not learn an additive bias.
-        latent_features (int or float, optional): size of the latent space.
+        bias (bool, optional): If set to False, the layer will not learn an additive bias.
+            Default: ``True``.
+        latent_features (int | float, optional): size of the latent space.
             Can be specified as either an integer > 1 or as a float within
             [0, 0.5). In the latter case, the value is interpreted as a fraction
             of ``min(in_features, out_features)``, and is converted to the
-            equivalent integer value, with a minimum of 1.
+            equivalent integer value, with a minimum of 1. Default: ``.25``.
 
     Raises:
         ValueError:
@@ -433,8 +436,8 @@ class FactorizedLinear(_FactorizedModule):
 
     @property
     def latent_features(self) -> int:
-        """The dimensionality of the space into which the input is projected by the first matrix in the
-        factorization."""
+        """The dimensionality of the space into which the input is 
+        projected by the first matrix in the factorization."""
         return self.latent_size
 
     def solution_for_rank(self, input: torch.Tensor, rank: int) -> LowRankSolution:
@@ -459,8 +462,8 @@ class FactorizedLinear(_FactorizedModule):
         """Returns the largest latent feature count that reduces the number of multiply-adds.
 
         Args:
-            in_features: size of each input sample
-            out_features: size of each output sample
+            in_features (int): size of each input sample
+            out_features (int): size of each output sample
 
         Returns:
             latent_features: the largest allowable number of latent features
