@@ -1,4 +1,5 @@
-# Copyright 2021 MosaicML. All Rights Reserved.
+# Copyright 2022 MosaicML Composer authors
+# SPDX-License-Identifier: Apache-2.0
 
 """Core MixUp classes and functions."""
 
@@ -131,7 +132,7 @@ class MixUp(Algorithm):
             return event in [Event.BEFORE_FORWARD, Event.BEFORE_LOSS]
 
     def apply(self, event: Event, state: State, logger: Logger) -> None:
-        input, target = state.batch_pair
+        input, target = state.batch
 
         if event == Event.BEFORE_FORWARD:
             if not isinstance(input, torch.Tensor):
