@@ -1,16 +1,18 @@
-# Copyright 2021 MosaicML. All Rights Reserved.
+# Copyright 2022 MosaicML Composer authors
+# SPDX-License-Identifier: Apache-2.0
 
 """Core code for Stochastic Weight Averaging."""
 
 from __future__ import annotations
 
 import logging
-from typing import Optional
+from typing import Any, Dict, List, Optional
 
 import torch
 from torch.optim.swa_utils import SWALR, AveragedModel
 
 from composer.core import Algorithm, Event, State, Time, TimeUnit
+from composer.core.types import PyTorchScheduler
 from composer.loggers import Logger
 
 log = logging.getLogger(__name__)
@@ -18,6 +20,11 @@ log = logging.getLogger(__name__)
 __all__ = ['SWA']
 
 
+def _assert_valid_duration(time: Time):
+    if time.unit == TimeUnit.DURATION and (time < 0 or time > 1):
+        raise ValueError(f'time in duration units must be [0, 1], got {time}')
+
+
 class SWA(Algorithm):
     """Apply Stochastic Weight Averaging (`Izmailov et al, 2018 <https://arxiv.org/abs/1803.05407>`_)
 
@@ -31,6 +38,11 @@ class SWA(Algorithm):
     memory required doubles, however, since stored activations and the
     optimizer state are not doubled.
 
+    .. note::
+
+       The AveragedModel is currently stored on the CPU device, which may
+       cause slow training if the model weights are large.
+
     Uses PyTorch's `torch.optim.swa_util
     <https://pytorch.org/docs/stable/optim.html#stochastic-weight-averaging>`_ under the
     hood.
@@ -109,44 +121,14 @@ class SWA(Algorithm):
         self.swa_lr = swa_lr
         self.swa_model: Optional[torch.nn.Module] = None
         self.swa_completed = False
+        self.swa_started = False
 
         # Check timestrings are parsable and convert into time objects
-        try:
-            self.swa_start = Time.from_timestring(swa_start)
-        except ValueError as error:
-            raise ValueError(f"Invalid time string for parameter swa_start") from error
-        try:
-            self.swa_end = Time.from_timestring(swa_end)
-        except ValueError as error:
-            raise ValueError(f"Invalid time string for parameter swa_end") from error
-        try:
-            self.update_interval = Time.from_timestring(update_interval)
-        except ValueError as error:
-            raise ValueError(f"Invalid time string for parameter update_interval") from error
+        self.swa_start = Time.from_timestring(swa_start)
+        self.swa_end = Time.from_timestring(swa_end)
+        self.update_interval = Time.from_timestring(update_interval)
 
-        # Check time objects have supported units
-        for time_attr in ["swa_start", "swa_end"]:
-            time_obj = getattr(self, time_attr)
-            if time_obj.unit not in [TimeUnit.DURATION, TimeUnit.EPOCH]:
-                raise ValueError(f"Invalid unit string for parameter {time_attr}: {time_obj.unit}")
-        if self.update_interval.unit not in [TimeUnit.BATCH, TimeUnit.EPOCH]:
-            raise ValueError(f"Invalid unit string for parameter update_interval: "
-                             f"{self.update_interval.unit}")
-
-        # Check time objects have valid values
-        if self.swa_start.unit == TimeUnit.DURATION:
-            if self.swa_start < 0 or self.swa_start >= 1:
-                raise ValueError("If swa_start is specified in units of 'dur', it must "
-                                 "be in the interval [0, 1).")
-        if self.swa_end.unit == TimeUnit.DURATION:
-            if self.swa_end == 1:
-                log.warning("'swa_end' = '1dur'. Batch norm statistics of averaged model "
-                            "will not be updated. This will negatively impact accuracy. "
-                            "See the documentation for the `swa_end` parameter for details.")
-            if self.swa_end > 1:
-                raise ValueError("If swa_end is specified in units of 'dur', it must be ≤1.")
-        if self.update_interval < 1:
-            raise ValueError("update_interval must be ≥ 1.")
+        self._validate_time()
 
         if anneal_steps <= 0:
             raise ValueError("anneal_steps must be greater than 0")
@@ -157,13 +139,13 @@ class SWA(Algorithm):
         elif self.anneal_strategy.lower() in ["cos", "cosine"]:
             self.anneal_strategy = "cos"
         else:
-            raise ValueError("Parameter 'anneal_strategy' must have an argument that is one of {'linear', 'cos'}.")
+            raise ValueError("anneal_strategy must be one of {'linear', 'cos'}.")
 
         self.swa_scheduler = None
         self.swa_model = None
 
         # Keeps track of # steps so that we can know when to update averaged model
-        self.step_counter = None
+        self.step_counter = 0
 
         # Check units for update_interval and set match event accordingly
         if self.update_interval.unit == TimeUnit.BATCH:
@@ -171,33 +153,67 @@ class SWA(Algorithm):
         elif self.update_interval.unit == TimeUnit.EPOCH:
             self.match_event = Event.EPOCH_END
 
-    def match(self, event: Event, state: State) -> bool:
-        if self.swa_start.unit == TimeUnit.DURATION:
-            should_start_swa = state.get_elapsed_duration() >= self.swa_start and not self.swa_completed
-        elif self.swa_start.unit == TimeUnit.EPOCH:
-            should_start_swa = state.timer.get("ep") >= self.swa_start and not self.swa_completed
+    def _validate_time(self):
+        # validate time units
+        if self.swa_start.unit != self.swa_end.unit:
+            raise ValueError(f'swa_start and swa_end must have same units, got {self.swa_start} and {self.swa_end}')
+        if self.swa_start.unit not in [TimeUnit.DURATION, TimeUnit.EPOCH]:
+            raise ValueError(f'swa_start must be DURATION or EPOCH, got {self.swa_start.unit}')
+        if self.update_interval.unit not in [TimeUnit.BATCH, TimeUnit.EPOCH]:
+            raise ValueError(f'update_iterval must be BATCH or EPOCH, got {self.update_interval.unit}')
+
+        # validate time
+        if self.swa_start >= self.swa_end:
+            raise ValueError('swa_end must be > swa_start.')
+        if self.swa_end.unit == TimeUnit.DURATION and self.swa_end == 1:
+            log.warning("'swa_end' = '1dur'. Batch norm statistics of averaged model "
+                        "will not be updated. This will negatively impact accuracy. "
+                        "See the documentation for the `swa_end` parameter for details.")
+
+        _assert_valid_duration(self.swa_start)
+        _assert_valid_duration(self.swa_end)
+
+    def _get_time(self, state: State):
+        """helper function to retrieve either the epoch or the duration depending on the units"""
+        unit = self.swa_start.unit
+
+        if unit == TimeUnit.EPOCH:
+            return state.timestamp.epoch
+        elif unit == TimeUnit.DURATION:
+            time_elapsed = state.get_elapsed_duration()
+            assert time_elapsed is not None, "Time should have been set on BATCH_END or EPOCH_END."
+            return time_elapsed
         else:
-            should_start_swa = False
-        return event == self.match_event and should_start_swa
+            raise ValueError('units must be in epoch or duration.')
 
-    def apply(self, event: Event, state: State, logger: Logger) -> None:
-        if self.step_counter is None:
-            self.step_counter = 0
+    def _get_last_lr(self, schedulers: List[PyTorchScheduler]):
+        """ retrieves the last lr from current schedulers. """
+        if len(schedulers) == 0:
+            return 1.0
+        if len(schedulers) != 1:
+            raise RuntimeError(f"SWA supports only one scheduler, got {len(schedulers)}")
+        scheduler = schedulers[0]
+        last_lr = scheduler.get_last_lr()
+        if len(last_lr) != 1:
+            raise RuntimeError(f"SWA supports only one LR; instead found {len(last_lr)}")
+        return last_lr[0]
 
-        if self.swa_scheduler is None and self.schedule_swa_lr:
+    def match(self, event: Event, state: State) -> bool:
+        if event == Event.INIT:
+            return True
 
-            if self.swa_lr is None:
-                if len(state.schedulers) != 1:
-                    raise RuntimeError("SWA supports only one scheduler")
-                scheduler = state.schedulers[0]
-                last_lr = scheduler.get_last_lr()
-                if len(last_lr) != 1:
-                    raise RuntimeError(f"SWA supports only one LR; instead found {len(last_lr)}")
-                log.info(f'Setting SWA LR to {last_lr}')
-                self.swa_lr = last_lr[0]
+        # only match on BATCH_END or EPOCH_END, depending on the setting
+        if event != self.match_event or self.swa_completed:
+            return False
+
+        return self._get_time(state) >= self.swa_start
+
+    def _initialize_swa(self, state: State) -> None:
+        if self.schedule_swa_lr:
+            self.swa_lr = self._get_last_lr(state.schedulers)
 
             if len(state.optimizers) != 1:
-                raise RuntimeError("SWA supports one and only one optimizer")
+                raise RuntimeError("SWA supports only one optimizer")
 
             self.swa_scheduler = SWALR(
                 state.optimizers[0],
@@ -206,29 +222,69 @@ class SWA(Algorithm):
                 anneal_strategy=self.anneal_strategy,
             )
 
+        self.swa_model = AveragedModel(state.model, device=torch.device('cpu'))
+
+    def apply(self, event: Event, state: State, logger: Logger) -> None:
+
+        if event == event.INIT:
+            # on trainer init, we create the schedulers and models
+            # so that the checkpoints can be loaded
+            self._initialize_swa(state)
+            return
+
+        if not self.swa_started:
+            # re-initialize swa once time > swa_start
+            self._initialize_swa(state)
+            self.swa_started = True
+
         if self.step_counter % self.update_interval.value == 0:
-            if self.swa_model is None:
-                self.swa_model = AveragedModel(state.model)
+            assert self.swa_model is not None
 
             self.swa_model.update_parameters(state.model)  # type: ignore
 
             if self.schedule_swa_lr:
-                if self.swa_scheduler is None:
-                    raise ValueError('SWA LR scheduler was not set.')
+                assert self.swa_scheduler is not None
                 self.swa_scheduler.step()
 
         self.step_counter += 1
 
         # Determine whether it's time to end SWA
-        if self.swa_end.unit == TimeUnit.DURATION and (state.get_elapsed_duration() >= self.swa_end):
+        if self._get_time(state) >= self.swa_end:
             self.swa_completed = True
-        if self.swa_end.unit == TimeUnit.EPOCH and (state.timer.get("ep") >= self.swa_end):
-            self.swa_completed = True
-        if self.swa_completed:
+
             if state.get_elapsed_duration() == 1:
-                log.warning("The baseline model was replaced with the SWA model after the end of "
-                            "training. This means that SWA model will not have its batch norm "
-                            "statistics updated. This will negatively impact accuracy. See the "
-                            "documentation for the `swa_end` parameter for details.")
+                log.warning(("The baseline model was replaced with the SWA model after the end of "
+                             "training. This means that SWA model will not have its batch norm "
+                             "statistics updated. This will negatively impact accuracy. See the "
+                             "documentation for the `swa_end` parameter for details."))
+
             state.model.load_state_dict(self.swa_model.module.state_dict())  # type: ignore
             log.info('Set model to the averaged model')
+
+    def state_dict(self) -> Dict[str, Any]:
+
+        # we pop the anneal_func from the SWALR state
+        # since it is set in the SWALR __init__
+        swa_scheduler_state = None
+        if self.swa_scheduler:
+            swa_scheduler_state = self.swa_scheduler.state_dict()
+            swa_scheduler_state.pop('anneal_func')
+
+        state_dict = {
+            'swa_model': self.swa_model.state_dict() if self.swa_model else None,
+            'swa_completed': self.swa_completed,
+            'swa_started': self.swa_started,
+            'swa_scheduler': swa_scheduler_state,
+            'step_counter': self.step_counter,
+        }
+        return state_dict
+
+    def load_state_dict(self, state: Dict[str, Any]) -> None:
+        self.swa_completed = state['swa_completed']
+        self.step_counter = state['step_counter']
+        self.swa_started = state['swa_started']
+
+        if self.swa_scheduler and state['swa_scheduler']:
+            self.swa_scheduler.load_state_dict(state['swa_scheduler'])
+        if self.swa_model and state['swa_model']:
+            self.swa_model.load_state_dict(state['swa_model'])
