@@ -1,4 +1,5 @@
-# Copyright 2021 MosaicML. All Rights Reserved.
+# Copyright 2022 MosaicML Composer authors
+# SPDX-License-Identifier: Apache-2.0
 
 """Engine is a coordinator for running algorithms and resolving ordering conflicts among them for composition.
 
@@ -63,6 +64,7 @@ from __future__ import annotations
 import atexit
 import contextlib
 import logging
+import weakref
 from collections import OrderedDict
 from dataclasses import dataclass
 from typing import ContextManager, Dict, Optional, Sequence, Union, cast
@@ -84,6 +86,25 @@ __all__ = ["Trace", "Engine", "Traces"]
 Traces = Dict[str, "Trace"]
 
 _ALWAYS_RECORD_EVENTS = [Event.INIT, Event.FIT_START, Event.EPOCH_START, Event.EPOCH_END]
+_EVENTS_WHERE_DATALOADER_IS_SET = [e for e in Event if e != Event.INIT]
+_EVENTS_WHERE_MAX_DURATION_IS_SET = [
+    Event.FIT_START,
+    Event.EPOCH_START,
+    Event.BATCH_START,
+    Event.AFTER_DATALOADER,
+    Event.BEFORE_TRAIN_BATCH,
+    Event.BEFORE_FORWARD,
+    Event.AFTER_FORWARD,
+    Event.BEFORE_LOSS,
+    Event.AFTER_LOSS,
+    Event.BEFORE_BACKWARD,
+    Event.AFTER_BACKWARD,
+    Event.AFTER_TRAIN_BATCH,
+    Event.BATCH_END,
+    Event.BATCH_CHECKPOINT,
+    Event.EPOCH_END,
+    Event.EPOCH_CHECKPOINT,
+]
 
 # Track whether atexit triggered _close(), which indicates whether the python process is shutting down
 # If so, do not run close() again via __del__(), as Python machinery (e.g. the ability to do conditional
@@ -107,8 +128,8 @@ class Trace():
     """Record of an algorithm's execution.
 
     Attributes:
-        exit_code (int or None): Optional return value from an algorithm. Default: None.
-        order (int or None): Order in which the algorithm was executed
+        exit_code (int | None): Optional return value from an algorithm. Default: None.
+        order (int | None): Order in which the algorithm was executed
                              in the list of algorithms. None means algorithm was not run.
         run (bool): Whether the algorithm was run. Default: False
     """
@@ -126,6 +147,11 @@ def _setup_trace(algorithms: Sequence[Algorithm], event: Event) -> Traces:
     return OrderedDict([(f'{algo}/{event}', Trace()) for algo in algorithms])
 
 
+# Track which callbacks are already open, so it is possible to error and instruct the user to call
+# previous_trainer.close() if necessary before attempting to reuse a callback
+_OPEN_CALLBACKS = weakref.WeakSet()
+
+
 class Engine():
     """Coordinator for running algorithms and resolving ordering conflicts among them for composition.
 
@@ -172,7 +198,7 @@ class Engine():
 
 
         Args:
-            event (Event or str): The current :class:`~.event.Event`. It can be the enum member values or a
+            event (Event | str): The current :class:`~.event.Event`. It can be the enum member values or a
                 string with the event value.
         Returns:
             traces (Traces): Ordered dictionary of trace for each algorithm.
@@ -197,6 +223,12 @@ class Engine():
         if event.is_after_event and duration_marker is not None:
             duration_marker.finish()
 
+        if event in _EVENTS_WHERE_DATALOADER_IS_SET:
+            assert self.state.dataloader is not None, f"The trainer should have set state.dataloader for event {event}."
+
+        if event in _EVENTS_WHERE_MAX_DURATION_IS_SET:
+            assert self.state.max_duration is not None, f"The trainer should have set state.max_duration for event {event}."
+
         if event == Event.INIT:
             # For the INIT event, run the callbacks first to initialize the loggers
             # For other events, run the algorithms first, so the callbacks have the state
@@ -302,6 +334,19 @@ class Engine():
         """
         event = Event(event)
 
+        if event == Event.INIT:
+            # Some callbacks may be open from a previous training run
+            # If so, error and instruct the user that they must call `trainer.close()`
+            # so callbacks can clean up and reset their state properly
+            for cb in self.state.callbacks:
+                # If it's not in the dictionary, then the callback is new, so it's closed by definition
+                if cb in _OPEN_CALLBACKS:
+                    raise RuntimeError(
+                        ("Cannot create a new trainer with an open callback or logger from a previous trainer. "
+                         "To fix, call trainer.close() before creating this new trainer to ensure that all "
+                         "callbacks or loggers shut down properly."))
+                _OPEN_CALLBACKS.add(cb)
+
         for cb in self.state.callbacks:
             marker = None
             if self.state.profiler is not None:
@@ -316,15 +361,13 @@ class Engine():
 
     def __del__(self):
         global _did_atexit_run
-        if _did_atexit_run:
-            # Do not attempt to shutdown again, since close() already ran via __atexit__
-            # In this case, close() is no longer idempotent, since Python machenry (such as the ability to do
-            # conditional imports) has already been destroyed
+        if _did_atexit_run or self._is_closed:
+            # Do not attempt to shutdown again, since close() already ran via __atexit__ or was already invoked
             return
         self.close()
 
     def close(self) -> None:
-        """Shutdown the enginge.
+        """Shutdown the engine.
 
         As part of the shutdown procedure, :meth:`~.Callback.close` and :meth:`~.Callback.post_close` is invoked
         for each callback. Note that :meth:`~.Callback.post_close` is invoked only for callbacks that did not raise
@@ -362,3 +405,5 @@ class Engine():
                     callback.post_close()
                 except Exception as e:
                     log.error(f"Error running {callback.__class__.__name__}.post_close().", exc_info=e, stack_info=True)
+                else:
+                    _OPEN_CALLBACKS.discard(callback)
