@@ -1,4 +1,5 @@
-# Copyright 2021 MosaicML. All Rights Reserved.
+# Copyright 2022 MosaicML Composer authors
+# SPDX-License-Identifier: Apache-2.0
 
 """ADE20K Semantic segmentation and scene parsing dataset.
 
@@ -8,8 +9,9 @@ dataset.
 
 import os
 from dataclasses import dataclass
+from io import BytesIO
 from math import ceil
-from typing import Optional, Tuple, Union
+from typing import Any, Optional, Tuple, Union
 
 import numpy as np
 import torch
@@ -20,13 +22,15 @@ from torch.utils.data import Dataset
 from torchvision import transforms
 
 from composer.core import DataSpec
+from composer.datasets.dataloader import DataLoaderHparams
 from composer.datasets.hparams import DatasetHparams, SyntheticHparamsMixin, WebDatasetHparams
 from composer.datasets.imagenet import IMAGENET_CHANNEL_MEAN, IMAGENET_CHANNEL_STD
+from composer.datasets.streaming import StreamingDataset
 from composer.datasets.synthetic import SyntheticBatchPairDataset
 from composer.datasets.utils import NormalizationFn, pil_image_collate
 from composer.utils import dist
 
-__all__ = ["ADE20k", "ADE20kDatasetHparams", "ADE20kWebDatasetHparams"]
+__all__ = ["ADE20k", "ADE20kDatasetHparams", "ADE20kWebDatasetHparams", "StreamingADE20k", "StreamingADE20kHparams"]
 
 
 class RandomResizePair(torch.nn.Module):
@@ -388,6 +392,160 @@ class ADE20kDatasetHparams(DatasetHparams, SyntheticHparamsMixin):
                         device_transforms=device_transform_fn)
 
 
+class StreamingADE20k(StreamingDataset):
+    """
+    Implementation of the ADE20k dataset using StreamingDataset.
+
+    Args:
+        remote (str): Remote directory (S3 or local filesystem) where dataset is stored.
+        local (str): Local filesystem directory where dataset is cached during operation.
+        split (str): The dataset split to use, either 'train' or 'val'.
+        shuffle (bool): Whether to shuffle the samples in this dataset.
+        base_size (int): initial size of the image and target before other augmentations. Default: ``512``.
+        min_resize_scale (float): the minimum value the samples can be rescaled. Default: ``0.5``.
+        max_resize_scale (float): the maximum value the samples can be rescaled. Default: ``2.0``.
+        final_size (int): the final size of the image and target. Default: ``512``.
+        batch_size (Optional[int]): Hint the batch_size that will be used on each device's DataLoader. Default: ``None``.
+    """
+
+    def decode_uid(self, data: bytes) -> str:
+        return data.decode('utf-8')
+
+    def decode_image(self, data: bytes) -> Image.Image:
+        return Image.open(BytesIO(data))
+
+    def decode_annotation(self, data: bytes) -> Image.Image:
+        return Image.open(BytesIO(data))
+
+    def __init__(self,
+                 remote: str,
+                 local: str,
+                 split: str,
+                 shuffle: bool,
+                 base_size: int = 512,
+                 min_resize_scale: float = 0.5,
+                 max_resize_scale: float = 2.0,
+                 final_size: int = 512,
+                 batch_size: Optional[int] = None):
+
+        # Validation
+        if split not in ['train', 'val']:
+            raise ValueError(f"split='{split}' must be one of ['train', 'val'].")
+        if base_size <= 0:
+            raise ValueError("base_size must be positive.")
+        if min_resize_scale <= 0:
+            raise ValueError("min_resize_scale must be positive")
+        if max_resize_scale <= 0:
+            raise ValueError("max_resize_scale must be positive")
+        if max_resize_scale < min_resize_scale:
+            raise ValueError("max_resize_scale cannot be less than min_resize_scale")
+        if final_size <= 0:
+            raise ValueError("final_size must be positive")
+
+        # Build StreamingDataset
+        decoders = {
+            'image': self.decode_image,
+            'annotation': self.decode_annotation,
+        }
+        super().__init__(remote=os.path.join(remote, split),
+                         local=os.path.join(local, split),
+                         shuffle=shuffle,
+                         decoders=decoders,
+                         batch_size=batch_size)
+
+        # Define custom transforms
+        if split == 'train':
+            self.both_transform = torch.nn.Sequential(
+                RandomResizePair(min_scale=min_resize_scale,
+                                 max_scale=max_resize_scale,
+                                 base_size=(base_size, base_size)),
+                RandomCropPair(
+                    crop_size=(final_size, final_size),
+                    class_max_percent=0.75,
+                    num_retry=10,
+                ),
+                RandomHFlipPair(),
+            )
+
+            # Photometric distoration values come from mmsegmentation:
+            # https://github.com/open-mmlab/mmsegmentation/blob/master/mmseg/datasets/pipelines/transforms.py#L837
+            r_mean, g_mean, b_mean = IMAGENET_CHANNEL_MEAN
+            self.image_transform = torch.nn.Sequential(
+                PhotometricDistoration(brightness=32. / 255, contrast=0.5, saturation=0.5, hue=18. / 255),
+                PadToSize(size=(final_size, final_size), fill=(int(r_mean), int(g_mean), int(b_mean))))
+
+            self.annotation_transform = PadToSize(size=(final_size, final_size), fill=0)
+        else:
+            self.both_transform = None
+            self.image_transform = transforms.Resize(size=(final_size, final_size),
+                                                     interpolation=TF.InterpolationMode.BILINEAR)
+            self.annotation_transform = transforms.Resize(size=(final_size, final_size),
+                                                          interpolation=TF.InterpolationMode.NEAREST)
+
+    def __getitem__(self, idx: int) -> Tuple[Any, Any]:
+        obj = super().__getitem__(idx)
+        x = obj['image']
+        y = obj['annotation']
+        if self.both_transform:
+            x, y = self.both_transform((x, y))
+        if self.image_transform:
+            x = self.image_transform(x)
+        if self.annotation_transform:
+            y = self.annotation_transform(y)
+        return x, y
+
+
+@dataclass
+class StreamingADE20kHparams(DatasetHparams):
+    """DatasetHparams for creating an instance of StreamingADE20k.
+
+    Args:
+        remote (str): Remote directory (S3 or local filesystem) where dataset is stored.
+            Default: ``'s3://mosaicml-internal-dataset-ade20k/mds/1/```
+        local (str): Local filesystem directory where dataset is cached during operation.
+            Default: ``'/tmp/mds-cache/mds-ade20k/```
+        split (str): The dataset split to use, either 'train' or 'val'. Default: ``'train```.
+        base_size (int): initial size of the image and target before other augmentations. Default: ``512``.
+        min_resize_scale (float): the minimum value the samples can be rescaled. Default: ``0.5``.
+        max_resize_scale (float): the maximum value the samples can be rescaled. Default: ``2.0``.
+        final_size (int): the final size of the image and target. Default: ``512``.
+        ignore_background (bool): if true, ignore the background class when calculating the training loss.
+            Default: ``true``.
+    """
+
+    remote: str = hp.optional("Remote directory (S3 or local filesystem) where dataset is stored",
+                              default="s3://mosaicml-internal-dataset-ade20k/mds/1/")
+    local: str = hp.optional("Local filesystem directory where dataset is cached during operation",
+                             default="/tmp/mds-cache/mds-ade20k/")
+    split: str = hp.optional("Which split of the dataset to use. Either ['train', 'val']", default='train')
+    base_size: int = hp.optional("Initial size of the image and target before other augmentations", default=512)
+    min_resize_scale: float = hp.optional("Minimum value that the image and target can be scaled", default=0.5)
+    max_resize_scale: float = hp.optional("Maximum value that the image and target can be scaled", default=2.0)
+    final_size: int = hp.optional("Final size of the image and target", default=512)
+    ignore_background: bool = hp.optional("If true, ignore the background class in training loss", default=True)
+
+    def initialize_object(self, batch_size: int, dataloader_hparams: DataLoaderHparams) -> DataSpec:
+        dataset = StreamingADE20k(remote=self.remote,
+                                  local=self.local,
+                                  split=self.split,
+                                  shuffle=self.shuffle,
+                                  base_size=self.base_size,
+                                  min_resize_scale=self.min_resize_scale,
+                                  max_resize_scale=self.max_resize_scale,
+                                  final_size=self.final_size,
+                                  batch_size=batch_size)
+        collate_fn = pil_image_collate
+        device_transform_fn = NormalizationFn(mean=IMAGENET_CHANNEL_MEAN,
+                                              std=IMAGENET_CHANNEL_STD,
+                                              ignore_background=self.ignore_background)
+        return DataSpec(dataloader=dataloader_hparams.initialize_object(dataset=dataset,
+                                                                        batch_size=batch_size,
+                                                                        sampler=None,
+                                                                        collate_fn=collate_fn,
+                                                                        drop_last=self.drop_last),
+                        device_transforms=device_transform_fn)
+
+
 @dataclass
 class ADE20kWebDatasetHparams(WebDatasetHparams):
     """Defines an instance of the ADE20k dataset for semantic segmentation from a remote blob store.
