@@ -1,4 +1,5 @@
-# Copyright 2021 MosaicML. All Rights Reserved.
+# Copyright 2022 MosaicML Composer authors
+# SPDX-License-Identifier: Apache-2.0
 
 """Outputs profiling data in JSON trace format."""
 
@@ -257,7 +258,7 @@ class JSONTraceHandler(TraceHandler):
 
     def batch_end(self, state: State, logger: Logger) -> None:
         assert state.profiler is not None
-        timestamp = state.timer.get_timestamp()
+        timestamp = state.timestamp
         trace_folder = format_name_with_dist(self.folder, run_name=logger.run_name)
         if self._save_at_batch_end:
             # no longer active, but was previously active.
