@@ -1,4 +1,5 @@
-# Copyright 2021 MosaicML. All Rights Reserved.
+# Copyright 2022 MosaicML Composer authors
+# SPDX-License-Identifier: Apache-2.0
 
 """Profiler to collect :mod:`torch` performance metrics during training."""
 
@@ -180,7 +181,7 @@ class TorchProfiler(Callback):
         dist.barrier()
 
         def scheduler_fn(torch_profiler_step: int) -> TorchProfilerAction:
-            del torch_profiler_step  # the torch profiler step is unused. Using the composer timer instead.
+            del torch_profiler_step  # the torch profiler step is unused. Using the composer timestamp instead.
 
             assert state.profiler is not None
             composer_profiler_action = state.profiler.schedule(state)
@@ -197,7 +198,7 @@ class TorchProfiler(Callback):
 
             assert state.profiler is not None
 
-            timestamp = state.timer.get_timestamp()
+            timestamp = state.timestamp
 
             trace_file_name = os.path.join(
                 folder_name,
