@@ -1,17 +1,16 @@
-# Copyright 2021 MosaicML. All Rights Reserved.
+# Copyright 2022 MosaicML Composer authors
+# SPDX-License-Identifier: Apache-2.0
 
 """The CPU device used for training."""
 
 from __future__ import annotations
 
 import logging
-from contextlib import contextmanager
-from typing import Any, Dict, Generator, TypeVar, Union
+from typing import Any, Dict, TypeVar
 
 import torch
 
-from composer.core import Precision
-from composer.trainer.devices.device import Device, T_nnModule
+from composer.trainer.devices.device import Device
 
 logger = logging.getLogger(__name__)
 
@@ -35,14 +34,6 @@ class DeviceCPU(Device):
     def tensor_to_device(self, tensor: torch.Tensor) -> torch.Tensor:
         return tensor.to(self._device)
 
-    @contextmanager
-    def precision_context(self, precision: Union[str, Precision]) -> Generator[None, None, None]:
-        precision = Precision(precision)
-        if precision == Precision.FP32:
-            yield
-        else:
-            raise ValueError(f"Precision {precision} not supported for a CPU")
-
     def state_dict(self) -> Dict[str, Any]:
         # CPU device has no RNG state
         return {}
